@@ -3,10 +3,10 @@
 # HeeFramework
 # @Time    : 2020/11/10 15:06
 # @Author  : yanhu.zou
-__version__ = "1.0.22"
+__version__ = "1.0.24"
 
-import shutil
-import sys
+import datetime
+import json
 
 """
 HeeFramework
@@ -42,6 +42,9 @@ HeeFramework
 
 
 """
+
+import shutil
+import sys
 import os
 import importlib
 import inspect
@@ -49,18 +52,24 @@ import inspect
 import log4p
 from flask import Flask, Blueprint, request, send_from_directory
 
+from hee.heeconfig import Config
 
 print("heeframework start starts to initialize.")
 
-
 logger_ = log4p.GetLogger(logger_name=__name__, logging_level="INFO", config="config/log4p.json")
 log_ = logger_.logger
 
+# Import dependencies required by built-in modules before framework initialization.
+config = Config()
+if config.has_section('MYSQL'):
+    from hee.rdb_mysql import DbMySQL
+
+
+
 class HeeContainer:
     """
     submod and object container.
     """
-
     def __init__(self):
         # all submods
         self.submods: dict = {}
@@ -79,12 +88,10 @@ class HeeContainer:
             return self.submods[submod_name]
 
 
-
 class Hee:
     """
     Facade of Hee
     """
-
     def __init__(self, hee_container):
         super(Hee, self).__init__()
         self.__container = hee_container
@@ -97,17 +104,12 @@ class Hee:
         return self.__container.get_submod_by_name(name)
 
 
-
-
-
-
 class HeeApplication:
     """
     HeeApplication
     Building restful applications easily
     The user needs to create a class inherited from this class and execute the start method in the main function to start the application
     """
-
     def __init__(self):
         # Hee container
         self.hee_container = HeeContainer()
@@ -115,7 +117,31 @@ class HeeApplication:
         # Hee
         self.hee = Hee(self.hee_container)
 
-        self.cnt = 0
+        # Config
+        self.config = Config()
+
+        # dynami module MYSQL
+        if self.config.has_section('MYSQL'):
+            host_ = self.config.get_str('MYSQL', 'host')
+            port_ = self.config.get_int('MYSQL', 'port')
+            user_ = self.config.get_str('MYSQL', 'user')
+            password_ = self.config.get_str('MYSQL', 'pass')
+            db_ = self.config.get_str('MYSQL', 'db')
+            pool_max_ = self.config.get_int('MYSQL', 'pool_max')
+            pool_init_ = self.config.get_int('MYSQL', 'pool_init')
+            pool_idle_ = self.config.get_int('MYSQL', 'pool_idle')
+
+            # 初始化数据库管理
+            self.dbmysql = DbMySQL(
+                host=host_,
+                port=port_,
+                user=user_,
+                password=password_,
+                database=db_,
+                pool_init=pool_init_,
+                pool_max=pool_max_,
+                pool_idle=pool_idle_
+            )
 
         # Load all submods.
         log_.info('Start loading SubMod.')
@@ -149,19 +175,25 @@ class HeeApplication:
          Finally, all modules are loaded into the context.
         """
         log_.info("scan path: %s " % path)
-        self.cnt += 1
-        if path == './hee':
-            return
-
-        if path == '__pycache__':
-            return
 
         # Determine if it is a path, process the sub-path recursively
         if os.path.isdir(path):
             for subpath in os.listdir(path):
+                if subpath == './hee':
+                    return
+
+                if subpath.endswith('__pycache__'):
+                    return
+
+                if subpath == 'static':
+                    return
+
+                if subpath == 'template':
+                    return
+
                 self.scan_and_load_submod(path + "/" + subpath)
 
-        # If it is a main files, load the processing module
+        # If it is a python file, load the processing module
         elif path.endswith(".py"):
             # All files under the root path are skipped
             if path == 'hee_framework':
@@ -171,6 +203,10 @@ class HeeApplication:
             log_.info('Load submod: ' + submod_full_name)
             submod = importlib.import_module(submod_full_name)
 
+            # Automatic config injection
+            if 'config' in dir(submod):
+                submod.config = self.config
+
             # Automatic log injection
             if 'log' in dir(submod):
                 submod_logger = log4p.GetLogger(logger_name=submod_full_name, config="config/log4p.json")
@@ -182,6 +218,12 @@ class HeeApplication:
                 submod.hee = self.hee
                 log_.info("submod [" + submod_full_name + "] hee has been initialized.")
 
+            # -- flows are dynamic builtin module. --
+            # db_mysql dynamic module injection
+            if 'db' in dir(submod):
+                submod.db = self.dbmysql
+                log_.info("submod [" + submod_full_name + "] dynamic module has been initialized.")
+
             # save submods
             self.hee_container.submods[submod_full_name] = submod
 
@@ -255,8 +297,12 @@ class HeeRestApplication(HeeApplication):
     """
 
     def __init__(self):
+        static_path = os.getcwd() + os.path.sep + 'static'
+        template_path = os.getcwd() + os.path.sep + 'template'
+        log_.info("static file path: " + static_path)
+        log_.info("tempalte file path: " + template_path)
         super(HeeRestApplication, self).__init__()
-        self.heeFlask = Flask(__name__, static_folder="../static/", template_folder="../tempalte/")
+        self.heeFlask = Flask(__name__, static_folder=static_path, template_folder=template_path)
         self.web = Web(self.heeFlask)
         self.initialize_controller()
 
@@ -279,10 +325,30 @@ class HeeRestApplication(HeeApplication):
         log_.info("application is starting...")
         self.heeFlask.run(host=host, port=port)
 
+# Convert an object into a dict
+def object_to_dict(obj):
+    if isinstance(obj, dict):
+        return obj
+    else:
+        dict_data = {}
+        for name in dir(obj):
+            value = getattr(obj, name)
+            if not name.startswith('__') and not callable(value) and not name.startswith('_'):
+                dict_data[name] = value
+        return dict_data
+
+# Convert a dict to an object
+def dict_to_object(d: dict, t: type):
+    obj = t()
+    obj.__dict__.update(dict)
+    return obj
+
+
 class Web:
     """
     If you are building a web application, the web object will be injected into the controller when the controller is initialized. The web object provides the ability to process request parameters, request data acquisition, file download, upload, etc.
     """
+
     def __init__(self, flask: Flask):
         self.flask: Flask = flask
 
@@ -292,10 +358,28 @@ class Web:
     def request_data(self):
         return request.data
 
+    def request_json(self):
+        """
+        请求json数据
+        :return:
+        """
+        return json.loads(request.data)
+
     def request_files(self):
+        """
+        获取上传文件
+        :return:
+        """
         return request.files
 
-    def download(self, directory: str, file: str, **options):
+    def resp_download(self, directory: str, file: str, **options):
+        """
+        响应返回下载文件
+        :param directory:
+        :param file:
+        :param options:
+        :return:
+        """
         abs_download_dir = os.path.abspath(directory)
         # log_.info("abs_download_file: " + abs_download_dir)
         if not os.path.exists(abs_download_dir):
@@ -303,33 +387,66 @@ class Web:
         else:
             return send_from_directory(abs_download_dir, file, **options)
 
-    def static_file(self, filename: str):
+    def resp_static_file(self, filename: str):
+        """
+        响应返回静态文件
+        :param filename:
+        :return:
+        """
         return self.flask.send_static_file(filename)
 
+    def resp_json(self, data):
+        """
+        响应返回json数据。
+            1. 自动将 datetime 类型数据转为yyyy-MM-dd HH:mm:ss类型。
+            2. 自动将用户自定义类的对象转成json字符串，但以下划线打头的属性不进行转换。
+        :param data:
+        :return:
+        """
+        # 如果是用户自定义对象，则转成dict再序列化
+        if str(type(data)).__contains__('.'):
+            dict_data = object_to_dict(data)
+            return json.dumps(dict_data, cls=HeeJsonEncoder)
+        # 如果非用户自定义对象，则直接进行转换
+        else:
+            return json.dumps(data, cls=HeeJsonEncoder)
+
+# Hee Json Encoder
+class HeeJsonEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, datetime.datetime):
+            return obj.strftime("%Y-%m-%d %H:%M:%S")
+        else:
+            return json.JSONEncoder.default(self, obj)
+
+
+
 class HeeMapping(Blueprint):
     """
     Used to declare the request path, each controller needs to create an object of this type
     """
+
     def __init__(self, prefix: str):
         curframe = inspect.currentframe()
         calframe = inspect.getouterframes(curframe, 2)
         submod_name = calframe[1][0].f_locals['__name__']
         super(HeeMapping, self).__init__(name=submod_name, import_name=submod_name, url_prefix=prefix)
 
+
 class HeeWebApplication(HeeRestApplication):
     def __init__(self):
         self.initialize_default_dir()
         super(HeeWebApplication, self).__init__()
 
-
     def initialize_default_dir(self):
         """
         Initialize all default paths of the project.
         If it is a web project, it will directly initialize a static path and template path to prevent static files and template files
         :return:
         """
-        if not os.path.exists("static/"):
-            os.mkdir("static/")
+        root_path = os.getcwd()
+        if not os.path.exists(root_path + "/static/"):
+            os.mkdir(root_path + "/static/")
             log_.info("The static dir does not exists, create it.")
         if not os.path.exists("template/"):
             os.mkdir("template")
